@@ -1,6 +1,6 @@
 #### Binary ####
 
-# Internal function called by generate - returns Binary data
+# Internal function called by .generate - returns Binary data
 #
 # @param n The number of observations required in the data set
 # @param forumula String that specifies the formula for the probability
@@ -8,7 +8,7 @@
 # @param dtSim Incomplete simulated data.table
 # @return A data.frame column  with the updated simulated data
 
-getBinaryMean <- function(dtSim, formula, Size, link) {
+.getBinaryMean <- function(dtSim, formula, Size, link) {
   
   size <- with(dtSim, eval(parse(text = as.character(Size))))  
   
@@ -25,9 +25,9 @@ getBinaryMean <- function(dtSim, formula, Size, link) {
 
 }
 
-genbinom <- function(n, formula, Size, link, dtSim) {
+.genbinom <- function(n, formula, Size, link, dtSim) {
   
-  params <- getBinaryMean(dtSim, formula, Size, link)
+  params <- .getBinaryMean(dtSim, formula, Size, link)
 
   return(stats::rbinom(n, params[[2]], params[[1]]))
 
